@@ -429,7 +429,7 @@ void draw_phasecircle(void)
    int xc,yc;  /* coordinates of center */
    int r;      /* radius */
    int i,j,x,y;
-   double phase,step;
+   double phase;
    double rc,rs;
    double sintab[NC_phase/4];
    double costab[NC_phase/4];
@@ -437,7 +437,6 @@ void draw_phasecircle(void)
    r=winsize/10;
    xc=yc=r+r/2+1;
    SetLineAttributes(0, GDK_LINE_SOLID, GDK_CAP_ROUND, GDK_JOIN_ROUND);
-   step = 1/(2*M_PI*r) * 360;
 
    for (i=0;i<NC_phase/4;i++) {
       phase=((i*360.0/NC_phase)-phaseoffset)*M_PI/180.0;
