@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 2002-2005, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 2002-2005,2020 Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -393,7 +393,7 @@ int find_in_mask(Hidpoint *h, Maskpoint **pp, Hidpoint *h1)
       while (p->next) p=p->next;
    } else {
       while (p->next && p->next->a<a) p=p->next;
-      if (p->next && p->next->a==a && !p->a==a) p=p->next;
+      if (p->next && p->next->a==a && !(p->a==a)) p=p->next;
    }
    q=NEXT(p);
 /*
