@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011,2020 Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -356,7 +356,7 @@ int read_nec_GM(char *s)    /* GM -> coordinate transformation */
    double rox,roy,roz,xs,ys,zs;
    double mat[9],mmat[9];
    double co,si;
-   Wire *w00,*w0,*w1,*wlast;
+   Wire *w0,*w1,*wlast;
    Surface *s0,*s1;
    double its_double;
 
@@ -402,22 +402,18 @@ int read_nec_GM(char *s)    /* GM -> coordinate transformation */
 
    EXPAND_IF_NECESSARY(numwires*(nrpt+1),maxwires,wires)
    if (nrpt==0) {
-      w00=w1=wires;
+      w1=wires;
    } else {
-      w00=wires;
       w1=wires+numwires;
    }
-   wlast=wires+numwires;
-   while (w00<wlast) {
-      if (w00->itg>=its) {
-         w0=w00;
-         i=0;
-         do {
-            if (nrpt>0) {
-               numwires++;
-            } else {
-               w1=w0;
-            }
+
+   w0=wires;
+   i=0;
+   do {
+      wlast=wires+numwires;
+
+      while (w0<wlast) {
+         if (w0->itg>=its) {
             pointtransf(&w0->p0,&w1->p0,mat,xs,ys,zs);
             pointtransf(&w0->p1,&w1->p1,mat,xs,ys,zs);
             w1->rad=w0->rad;
@@ -426,13 +422,12 @@ int read_nec_GM(char *s)    /* GM -> coordinate transformation */
             else w1->itg=w0->itg;
             w1->abs=nextabs; nextabs+=w1->ns;
             w1->dispnr=w0->dispnr;
-            w0=w1;
             w1++;
-         } while (++i < nrpt);
+            numwires++;
+         }
+         w0++;
       }
-      w00++;
-   }
-
+   } while (++i < nrpt);
 
    if (nrpt==0) {
       s0=s1=surfaces;
