@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011,2020 Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -175,8 +175,11 @@ void find_fb(NECoutput *ne,Radpattern *r)
          }
       }
 
-      theta=ne->d[Neco_gsize*(k+1)+Neco_poltheta]*M_PI/180;
-      phi=ne->d[Neco_gsize*(k+1)+Neco_polphi]*M_PI/180;
+      if (k<POLrhcp) {
+         // load theta and phi relevant for next iteration, but skip in last iteration to avoid reading beyond end of array
+         theta=ne->d[Neco_gsize*(k+1)+Neco_poltheta]*M_PI/180;
+         phi=ne->d[Neco_gsize*(k+1)+Neco_polphi]*M_PI/180;
+      }
    }
 }
 
@@ -634,11 +637,11 @@ void read_nec_output_nearfield(FILE *f, NECoutput *ne,int magnetic)      /* trie
    char *p;
    Nearfield *nf,*np;
 
-   /* skip some column labels etc., until we find a line that starts with a digit, possibly preceeded by a minus */
+   /* skip some column labels etc., until we find a line that starts with a digit, possibly preceeded by a minus and/or a (decimal) point */
    do {
       fgets(s,200,f);
       p=s;
-      while (*p==' ' || *p=='-') p++;
+      while (*p==' ' || *p=='-' || *p=='.') p++;
    } while (!isdigit(*p) && !feof(f));
 
    do {
