@@ -1,6 +1,6 @@
 /*  XNECVIEW - a program for visualizing NEC2 input and output data
  *
- *  Copyright (C) 1998-2006,2011, Pieter-Tjerk de Boer -- pa3fwm@amsat.org
+ *  Copyright (C) 1998-2006,2011,2020 Pieter-Tjerk de Boer -- pa3fwm@amsat.org
  *
  *  Distributed on the conditions of version 2 of the GPL: see the files
  *  README and COPYING, which accompany this source file.
@@ -277,7 +277,7 @@ int write_png(int which,const char *filename)
       fclose(f);
       return 1;
    }
-   if (setjmp(pp->jmpbuf)) {
+   if (setjmp(png_jmpbuf(pp))) {
       png_destroy_write_struct(&pp,&ip);
       fclose(f);
       gdk_image_destroy(image);
@@ -298,7 +298,7 @@ int write_png(int which,const char *filename)
       for (x=0;x<width;x++) {
          guint32 u;
          u = gdk_image_get_pixel(image, x, y);
-         for(i=0;i<NC;i++) if (col[i].pixel==u) break;
+         for(i=0;i<NC;i++) if (0==((col[i].pixel^u)&0xffffff)) break;    // the 0xff000000 byte doesn't match in later GDK versions, presumably an alpha channel gets squeezed in, incompatibly with older GDK versions
          buf[x]=i;
       }
       png_write_row(pp,buf);
